Lighthouse has a new layout. Prefer the old one? Return to the old layout, and switch back any time from the link at the top of each page.

Jim Lindley's latest activity

Saturday, August 09 2008
564 dangerous float operations was updated in Ruby on Rails
756 Nested fields_for doesn't work when passed name of field was updated in Ruby on Rails
  • Jim Lindley
    Jim Lindley commented at 9:55 PM

    Glenn,

    This is currently expected although of course frustrating. Some work is being done in edge to alleviate this issue.

    There is a discussion going on in r...

785 Caching models fails in development was updated in Ruby on Rails
  • Jim Lindley
    Jim Lindley commented at 9:26 PM

    Maybe dup objects before storing them, and then dup them on retrieval and return the copies to prevent tainting the cache?

    Dup is even faster then marshal.

  • Jim Lindley
    Jim Lindley commented at 5:55 PM

    Yeah, about an order of magnitude.

  • Jim Lindley
    Jim Lindley commented at 5:27 PM

    Oh wait, my math was based off reloading strings. It's worse then I thought in my previous comment, sorry.

  • Jim Lindley
    Jim Lindley commented at 5:25 PM

    Some quick and dirty micro-benchmarking: http://gist.github.com/4683

    Basically, marshaling is 20x slower to save and 100x slower to load.

    However, Marshalling...